==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-admin/lxqt-admin-user/lxqt-admin-user_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Csoportbeállítás</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Csoportnév:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Csoport ID:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>A csoport tagjai:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>The group ID is in use.</source>
        <translation type="vanished">Csoport ID foglalt.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Csoportnév nem lehet üres.</translation>
    </message>
    <message>
        <source>The group name is in use.</source>
        <translation type="vanished">Csoportnév foglalt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Felhasználók és csoportok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Felhasználók</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="56"/>
        <source>Login Name</source>
        <translation>Bejelenkezési név</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="61"/>
        <source>User ID</source>
        <translation>Felhasználó ID</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="66"/>
        <source>Full Name</source>
        <translation>Teljes név</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="71"/>
        <source>Group</source>
        <translation>Csoport</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="76"/>
        <source>Home Directory</source>
        <translation>Saját könyvtár</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Rendszer felhasználók is látszanak (csak haladóknak)</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Csoportok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="108"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="113"/>
        <source>Group ID</source>
        <translation>Csoport ID</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="118"/>
        <source>Members</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="131"/>
        <source>toolBar</source>
        <translation>eszközsáv</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="158"/>
        <source>Add</source>
        <translation>Hozzáad</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="161"/>
        <source>Add new users or groups</source>
        <translation>Új felhasználó, vagy csoport hozzáadása</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="170"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Delete selected item</source>
        <translation>Kiválasztott törlése</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="182"/>
        <source>Properties</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="185"/>
        <source>edit properties of the selected item</source>
        <translation>A választott elem módosítása</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="194"/>
        <source>Refresh</source>
        <translation>Frisítés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="197"/>
        <source>Refresh the lists</source>
        <translation>Lista frissítése</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="206"/>
        <source>Change Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="209"/>
        <source>Change password for the selected user or group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Hiba</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="164"/>
        <location filename="../../../mainwindow.cpp" line="176"/>
        <location filename="../../../mainwindow.cpp" line="197"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="164"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Tényleg töröljük az illető felhasználót?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="176"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Tényleg töröljük az illető csoportot?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="187"/>
        <source>Input the new password for %1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="197"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Felhasználó beállítása</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Alap</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Teljes név:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Bejelenkezési név:</translation>
    </message>
    <message>
        <source>Set password:</source>
        <translation type="vanished">Jelszóbeállítás:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Felhasználó ID:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Főcsoport:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Bővített</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Parancsértelmező:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Saját könyvtár:</translation>
    </message>
    <message>
        <source>Change password:</source>
        <translation type="vanished">Jelszóváltoztatás:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>The user ID is in use.</source>
        <translation type="vanished">Felhasználó ID foglalt.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>The user name cannot be empty.</source>
        <translation>Felhasználónév nem lehet üres.</translation>
    </message>
    <message>
        <source>The user name is in use.</source>
        <translation type="vanished">Felhasználónév foglalt.</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="vanished">Megerősítés</translation>
    </message>
    <message>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation type="vanished">Üres legyen a jelszava a felhasználónak?</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../../../usermanager.cpp" line="224"/>
        <source>lxqt-admin-user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../usermanager.cpp" line="225"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-admin/lxqt-admin-user/lxqt-admin-user_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Csoportbeállítás</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Csoportnév:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Csoport ID:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>A csoport tagjai:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>The group ID is in use.</source>
        <translation type="vanished">Csoport ID foglalt.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Csoportnév nem lehet üres.</translation>
    </message>
    <message>
        <source>The group name is in use.</source>
        <translation type="vanished">Csoportnév foglalt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Felhasználók és csoportok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Felhasználók</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Bejelenkezési név</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>Felhasználó ID</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Teljes név</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Csoport</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Saját könyvtár</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Rendszer felhasználók is látszanak (csak haladóknak)</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Csoportok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>Csoport ID</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Tagok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="134"/>
        <source>toolBar</source>
        <translation>eszközsáv</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation>Hozzáad</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation>Új felhasználó, vagy csoport hozzáadása</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation>Kiválasztott törlése</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="188"/>
        <source>edit properties of the selected item</source>
        <translation>A választott elem módosítása</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation>Lista frissítése</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation>Jelszó váltás</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation>Felhasználó, vagy csoport jelszavának megváltoztatása</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Hiba</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Tényleg töröljük az illető felhasználót?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Tényleg töröljük az illető csoportot?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="197"/>
        <source>Input the new password for %1:</source>
        <translation>%1 új jelszava:</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Biztos, hogy üres a jelszó?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Felhasználó beállítása</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Alap</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Teljes név:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Bejelenkezési név:</translation>
    </message>
    <message>
        <source>Set password:</source>
        <translation type="vanished">Jelszóbeállítás:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Felhasználó ID:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Főcsoport:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Csoportok</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>A felhasználó ezen csoportok tagja:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Parancsértelmező:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Saját könyvtár:</translation>
    </message>
    <message>
        <source>Change password:</source>
        <translation type="vanished">Jelszóváltoztatás:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>The user ID is in use.</source>
        <translation type="vanished">Felhasználó ID foglalt.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>The user name cannot be empty.</source>
        <translation>Felhasználónév nem lehet üres.</translation>
    </message>
    <message>
        <source>The user name is in use.</source>
        <translation type="vanished">Felhasználónév foglalt.</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="vanished">Megerősítés</translation>
    </message>
    <message>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation type="vanished">Üres legyen a jelszava a felhasználónak?</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../../../usermanager.cpp" line="224"/>
        <source>lxqt-admin-user</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../usermanager.cpp" line="225"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;A (%1) akció sikertelen:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
